StorageReadError

Enum StorageReadError 

pub enum StorageReadError {
    KeyNotFound,
    OutOfBounds,
}
Errors that can occur when reading from storage using StorageRead methods that write the result to a slice.

Variants



KeyNotFound

The requested key was not found in storage.



OutOfBounds

Attempted to read past the end of the stored value.